@@ -439,13 +439,14 @@ def from_dict(dict_repr: Dict):
     f"V1beta1{kind}",
     f"V2alpha1{kind}",
     f"V2beta1{kind}",
-    "V1Pod"
+    "V1Pod",
+    "V1Namespace",
+    "V1ConfigMap"
   ]
 
   for guess in class_guesses:
     try:
       getattr(kubernetes.client.models, guess)
-      print(f"win for {guess}")
       return api.deserialize(mocked_kube_http_resp, guess)
     except:
       pass
