@@ -5,7 +5,10 @@ from k8kat.auth.kube_broker import broker
 def create(**subs):
   default_labels = dict(app=subs['name'])
   labels = {**subs.get('labels', {}), **default_labels}
-  match_labels = {**labels, **subs.get('selector', {})}
+  def_match_labels = {**labels, **subs.get('selector', {})}
+  force_match_labels = subs.get('force_selector', None)
+  coerce_sel = force_match_labels is not None
+  match_labels = force_match_labels if coerce_sel else def_match_labels
 
   svc = broker.client.V1Service(
     api_version='v1',
